Index: src/snapshot/serializer.h |
diff --git a/src/snapshot/serializer.h b/src/snapshot/serializer.h |
index 46dd4a1401406af288f64f9a5c4da89351f1a3f3..45f891e190c53cc4c0c95ad34e42943fcc2caf1a 100644 |
--- a/src/snapshot/serializer.h |
+++ b/src/snapshot/serializer.h |
@@ -171,9 +171,13 @@ class Serializer : public SerializerDeserializer { |
// Emit alignment prefix if necessary, return required padding space in bytes. |
int PutAlignmentPrefix(HeapObject* object); |
- // Returns true if the object was successfully serialized. |
- bool SerializeKnownObject(HeapObject* obj, HowToCode how_to_code, |
- WhereToPoint where_to_point, int skip); |
+ // Returns true if the object was successfully serialized as hot object. |
+ bool SerializeHotObject(HeapObject* obj, HowToCode how_to_code, |
+ WhereToPoint where_to_point, int skip); |
+ |
+ // Returns true if the object was successfully serialized as back reference. |
+ bool SerializeBackReference(HeapObject* obj, HowToCode how_to_code, |
+ WhereToPoint where_to_point, int skip); |
inline void FlushSkip(int skip) { |
if (skip != 0) { |